@@ -101,6 +101,14 @@ function ActiveCommandChanged(id, cmdType)
   return widgetHandler:ActiveCommandChanged(id, cmdType)
 end
 
+function CameraRotationChanged(rotx, roty, rotz)
+  return widgetHandler:CameraRotationChanged(rotx, roty, rotz)
+end
+
+function CameraPositionChanged(posx, posy, posz)
+  return widgetHandler:CameraPositionChanged(posx, posy, posz)
+end
+
 function CommandNotify(id, params, options)
   return widgetHandler:CommandNotify(id, params, options)
 end
